@@ -95,7 +95,16 @@ liqcell *liqcell_new()
 liqcell * liqcell_hold(liqcell *self)
 {
 	// use this to hold onto an object which someone else created
+
+
+
 	if(self)self->usagecount++;
+    
+	int imgc=0;
+	if(self->image)imgc=self->image->usagecount;
+	//liqapp_log("liqcell hold %s::%i::%i",self->name,self->usagecount,imgc);
+
+
 	return self;
 }
 
@@ -122,18 +131,37 @@ void liqcell_release(liqcell *self)
  */
 void liqcell_free(liqcell *self)
 {
-	//liqapp_log("liqcell freeing tree %s",self->name);
+	//liqapp_log("liqcell freeing tree %s:%s",self->name,self->classname?self->classname:"");
 	// never call _free directly, outside sources should _release the object
 
 	// these char* objects should really be results from the strings tree
 	// and hence need dereferencing before use, decide later not important for now
 	
+
+    
+    // time to notify everyone about our impending death.
+    liqcell_handlerrun(self,"destroy",NULL);
+    
 	if(self->linkparent)
 	{
 		//
 		//liqcell_release(self->linkparent);
 		self->linkparent=NULL;
-	}
+	}    
+    
+    if( self->classname && (strcmp(self->classname,"liqtimer")==0) )
+    {
+        // cheat to close down the thread!
+        pthread_t 		*tid = liqcell_getdata(self);
+        if(tid)
+        {
+            // only live once...
+            liqapp_log("liqcell_free thread cancelling for '%s'",self->name);
+            pthread_cancel(*tid);
+            tid=NULL;
+            liqapp_log("liqcell_free thread cancelled for '%s'",self->name);
+       }
+    }
 	
 	
 	liqcell *c=self->linkchild;
@@ -170,13 +198,7 @@ void liqcell_free(liqcell *self)
 		
 		c=d;
 	}
-	
-	if(self->linkparent)
-	{
-		//
-		//liqcell_release(self->linkparent);
-		self->linkparent=NULL;
-	}
+
 	
 	//liqapp_log("liqcell freeing contents %s",self->name);
 	liqcell_setname(self,NULL);
@@ -666,7 +688,9 @@ void liqcell_setcontent(liqcell *self,liqcell *content)
 		liqcell_release(self->content);
 		self->content=NULL;
 	}
-	if(content){      self->content      = liqcell_hold(content);    }//       liqcell_setdirty(self,1);    }
+	//if(content){      self->content      = liqcell_hold(content);    }//       liqcell_setdirty(self,1);    }
+	if(content){      self->content      = (content);    }//       liqcell_setdirty(self,1);    }
+
 }
 
 /**
@@ -810,9 +834,9 @@ liqcell *liqcell_getlinknext(liqcell *self)
 }
 
 /**
- * Get the linked previous of the liqcell, the previous link in the linked list that is VISIBLE
+ * Get the linked previous of the liqcell, the previous link in the linked list that is VISUAL - though may be hidden
  * @param self The liqcell to lookup
- * @return liqcell* Liqcell pointer to the first previous that is visible
+ * @return liqcell* Liqcell pointer to the first previous that is visual
  */
 liqcell *liqcell_getlinkprev_visual(liqcell *self)
 {
@@ -826,9 +850,9 @@ liqcell *liqcell_getlinkprev_visual(liqcell *self)
 }
 
 /**
- * Get the linked previous of the liqcell, the previous link in the linked list that is VISIBLE
+ * Get the linked previous of the liqcell, the previous link in the linked list that is VISUAL - though may be hidden
  * @param self The liqcell to lookup
- * @return liqcell* Liqcell pointer to the first previous that is visible
+ * @return liqcell* Liqcell pointer to the first previous that is visual
  */
 liqcell *liqcell_getlinknext_visual(liqcell *self)
 {
@@ -842,9 +866,9 @@ liqcell *liqcell_getlinknext_visual(liqcell *self)
 }
 
 /**
- * Get the linked child of the liqcell, the child link in the linked list that is VISIBLE
+ * Get the linked child of the liqcell, the child link in the linked list that is VISUAL - though may be hidden
  * @param self The liqcell to lookup
- * @return liqcell* Liqcell pointer to the first child that is visible
+ * @return liqcell* Liqcell pointer to the first child that is visual
  */
 liqcell *liqcell_getlinkchild_visual(liqcell *self)
 {
@@ -857,6 +881,59 @@ liqcell *liqcell_getlinkchild_visual(liqcell *self)
 	return NULL;
 }
 
+
+
+
+
+/**
+ * Get the linked previous of the liqcell, the previous link in the linked list that is VISIBLE - that is, set to show now
+ * @param self The liqcell to lookup
+ * @return liqcell* Liqcell pointer to the first previous that is visible
+ */
+liqcell *liqcell_getlinkprev_visible(liqcell *self)
+{
+	liqcell *c = self->linkprev;
+	while(c)
+	{
+		if(liqcell_getvisible(c))return c;
+		c=c->linkprev;
+	}
+	return NULL;
+}
+
+/**
+ * Get the linked previous of the liqcell, the previous link in the linked list that is VISIBLE - that is, set to show now
+ * @param self The liqcell to lookup
+ * @return liqcell* Liqcell pointer to the first previous that is visible
+ */
+liqcell *liqcell_getlinknext_visible(liqcell *self)
+{
+	liqcell *c = self->linknext;
+	while(c)
+	{
+		if(liqcell_getvisible(c))return c;
+		c=c->linknext;
+	}
+	return NULL;
+}
+
+/**
+ * Get the linked child of the liqcell, the child link in the linked list that is VISIBLE - that is, set to show now
+ * @param self The liqcell to lookup
+ * @return liqcell* Liqcell pointer to the first child that is visible
+ */
+liqcell *liqcell_getlinkchild_visible(liqcell *self)
+{
+	liqcell *c = self->linkchild;
+	while(c)
+	{
+		if(liqcell_getvisible(c))return c;
+		c=c->linknext;
+	}
+	return NULL;
+}
+
+
 /**
  * Return the linked child of the parent provided.
  * @param self The parent liqcell
@@ -1563,10 +1640,11 @@ liqcell* liqcell_child_lookup(liqcell *self,char *name)
 				//liqapp_log("dot5 %s",dot);
 				return y;
 			}
+			//liqapp_log("liqcell_child_lookup '%s' not found '%s'",self->name,name);
 			return NULL;
 		}
 		// invalid string
-		liqapp_log("liqcell_child_lookup failed strdup");
+		//liqapp_log("liqcell_child_lookup failed strdup");
 		return NULL;
 	}
 	
@@ -1580,6 +1658,7 @@ liqcell* liqcell_child_lookup(liqcell *self,char *name)
 		}
 		c=c->linknext;
 	}
+	//liqapp_log("liqcell_child_lookup '%s' not found '%s'",self->name,name);
 	return NULL;
 }
 
@@ -1708,7 +1787,14 @@ liqcell*  liqcell_global_lookup_nameclass(liqcell *self,char *name,char *classna
 liqcell*  liqcell_quickcreatewidget(char *name,char *classname,int innerw,int innerh)
 {
 	liqcell *self = liqcell_new();
-
+	if(classname && *classname)
+	{
+		if( (strcmp(classname,"form")==0) )
+		{
+			// Sat Aug 29 23:54:16 2009 lcuk : stupid thing, i gave everything as a form initially
+			classname=name;
+		}
+	}
 	liqcell_setname(self,name);
 	liqcell_setclassname(self,classname);
 	liqcell_setrect(self,0,0,innerw,innerh);
