@@ -223,6 +223,60 @@ void liqimage_cache_release(liqimage *self)
 
 
 
+
+
+liqimage *liqimage_getthumbnail(liqimage *original,int maxw,int maxh)
+{
+	// this function returns a thumbnail of the original image
+	
+	if(!original)return NULL;
+	int tw=original->width;
+	int th=original->height;
+	if(maxw && maxh)
+	{
+		while(tw>maxw)
+		{
+			tw/=2;
+			th/=2;
+		}
+		while(th>maxh)
+		{
+			tw/=2;
+			th/=2;
+		}
+	}
+	//if(tw==original->width && th==original->th)
+	//{
+	//	return NULL;
+	//}
+	liqimage *thumb = liqimage_newatsize(tw,th,0);
+	if(!thumb)
+	{
+		liqapp_log("thumb: could not allocate img");
+		return NULL;
+	}
+	liqcliprect *cr = liqcliprect_newfromimage(thumb);
+	if(!cr)
+	{
+		liqapp_log("thumb: could not allocate cr");
+		liqimage_release(thumb);
+		return original;
+	}	
+	liqcliprect_drawimagecolor(cr,original,0,0,tw,th,0);
+	liqcliprect_release(cr);
+	//liqimage_release(original);
+	return thumb;
+}
+
+
+
+
+
+
+
+
+
+
 //####################################################################
 //####################################################################
 //####################################################################
@@ -427,6 +481,7 @@ liqimage *liqimage_new()
 liqimage * liqimage_hold(liqimage *self)
 {
 	// use this to hold onto an object which someone else created
+	//liqapp_log( "liqimage hold  (%i,%i) %i", self->width,self->height,self->usagecount );
 	if(self)self->usagecount++;
 	return self;
 }
@@ -443,7 +498,7 @@ void liqimage_release(liqimage *self)
 
 void liqimage_free(liqimage *self)
 {
-	liqapp_log("liqimage free");
+	//liqapp_log("liqimage free");
 	liqimage_pagereset(self);
 	free(self);
 }
@@ -478,9 +533,10 @@ void liqimage_pagereset(liqimage *self)
 		if(self->pitches)free(self->pitches);
 		if(self->data)   free(self->data);		
 	}
-	
-	
-	memset((char *)self,0,sizeof(liqimage));	
+	// 20090624_020851 lcuk : GOTCHA!  you were being blanked to 0 every time this was called and not retaining the usagecount
+int uc=self->usagecount;
+	memset((char *)self,0,sizeof(liqimage));
+	self->usagecount=uc;
 }
 
 void liqimage_pagedefine(liqimage *self,int w,int h,int dpix,int dpiy,int hasalpha)	// result plane count: 3=YUV, 4=YUVA
@@ -830,78 +886,203 @@ int 							row_stride;
 //static image_info_t *decompress_png(const char *filename)
 int liqimage_pageloadpng(liqimage *self,char * filename,int maxw,int maxh,int allowalpha)
 {
+	return liqimage_pageloadpng_memstream(self,filename,NULL,0,maxw,maxh,allowalpha);
+}
 
 
+struct liqimage_png_membuffer
+{
+	int offset;
+	int size;
+	char *data;
+};
 
+// use the png_membuffer to supply data as expected to png library
+static void png_read_data(png_structp png_ptr, png_bytep area, png_size_t size)
+{
+	png_byte *n_data = (png_byte *)area;
 	
-	liqapp_log("png.opening '%s'",filename);
 	
-	FILE *fp = fopen(filename, "rb");
+	struct liqimage_png_membuffer *src;
+	src = (struct liqimage_png_membuffer *)png_get_io_ptr(png_ptr);
+	
+	
+	
+	//char mem[5];
+	//mem[0]=src->data[src->offset+0];
+	//mem[1]=src->data[src->offset+1];
+	//mem[2]=src->data[src->offset+2];
+	//mem[3]=src->data[src->offset+3];
+	//mem[4]=0;
+	//liqapp_log("png.read %i bytes wanted cursor (%i/%i) :: '%s' %02x,%02x,%02x,%02x",size,src->offset,src->size,mem,mem[0],mem[1],mem[2],mem[3]);
+	//SDL_RWread(src, area, size, 1);
+	if(src->offset+size >= src->size)
+	{
+		png_error(png_ptr, "png_read_data error, input past end");
+		return;
+	}
+	memcpy((char *)n_data,src->data+src->offset,size);
+	src->offset+=size;	
+}
+
+
+int liqimage_pageloadpng_memstream(liqimage *self,char * filename,char *srcdata, int srcsize,int maxw,int maxh,int allowalpha)
+{
+	// 20090715_224851 lcuk : srcdata and srcsize are memory array versions
+	// 20090715_224901 lcuk : pass NULL and 0 as well as a valid filename to use standard procedure
+	// 20090715_224901 lcuk : passing valid parameters in src*, and NULL filename results in using the memory for the file instead :)
+	struct liqimage_png_membuffer src;
+	src.offset=0;
+	src.size=srcsize;
+	src.data=srcdata;
+	
+	
+	FILE *fp=NULL;
+	
+	if(*filename)
+	{
+		liqapp_log("png.opening '%s'",filename);
+		fp = fopen(filename, "rb");
 		if (!fp)
 		{
 			liqapp_log("png.open failed %s", filename);
 			return -1;
 		}
-
+	}
+	else
+	{
+		liqapp_log("png.memory stream XYZ");
+	}
 
 	unsigned char  header[8];
 	
-		int ttt=fread(header, 1, 8, fp);
+		int ttt;
+	if(*filename)
+	{
+		ttt=fread(header, 1, 8, fp);
 		if(!ttt)
 		{
-			fclose(fp);
+			if(fp)fclose(fp);
 			return -2;			
 		}
-		int is_png = !png_sig_cmp(header, 0, 8);
+	}
+	else
+	{
+		if(srcsize<8)
+		{
+			return -2;			
+		}
+		// just copy the memory :)
+		memcpy(header,srcdata,8);
+		
+		//src.offset+=8;	// hmmm
+	}
+	
+		int is_png;
+		is_png = !png_sig_cmp(header, 0, 8);
 		if (!is_png)
 		{
-			fclose(fp);
+			liqapp_log("png.not an image");
+			if(fp)fclose(fp);
 			return -2;
 		}
 		
+		
+		
+		
+
+
+	//liqapp_log("png.reading struct");
+		
 	
 	png_structp png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
 		if (!png_ptr)
 		{
 			liqapp_log("png.png_ptr fail");
-			fclose(fp);
+			if(fp)fclose(fp);
 			return -3;
 		}
 		
+	//liqapp_log("png.setting jmpbuf");
 		
+    if (setjmp (png_jmpbuf (png_ptr)))
+	{
+		liqapp_log("png setjmp called, must have an error");
+		
+		{
+			png_destroy_read_struct(&png_ptr, (png_infopp)NULL, (png_infopp)NULL);
+			if(fp)fclose(fp);
+			return -3;
+		}
+	}
+	
+	
+	
+
+	//liqapp_log("png.creating info_struct");
+	
 		
 	png_infop info_ptr = png_create_info_struct(png_ptr);
 		if (!info_ptr)
 		{
 			liqapp_log("png.info_ptr fail");
 			png_destroy_read_struct(&png_ptr, (png_infopp)NULL, (png_infopp)NULL);
-			fclose(fp);
+			if(fp)fclose(fp);
 			return -4;
 		}
 		
+	//liqapp_log("png.creating end info");
+		
 		
 	png_infop end_info = png_create_info_struct(png_ptr);
 		if (!end_info)
 		{
 			liqapp_log("png.end_info fail");
 			png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
-			fclose(fp);
+			if(fp)fclose(fp);
 			return -5;
 		}
 		
 		
-		png_init_io(png_ptr, fp);		
+	if(*filename)
+	{
+	//	liqapp_log("png.init file io");
+		png_init_io(png_ptr, fp);
+	}
+	else
+	{
+	//	liqapp_log("png.assign read function");
+		png_set_read_fn(png_ptr, (char *)&src, png_read_data);
+		
+	}
+	
+	
+	if(*filename)
+	{
+	
+	//	liqapp_log("png.setting sigbytes (tell lib we skipped 8 bytes already)");
+	
+	
 		png_set_sig_bytes(png_ptr, 8);
 		
+		// leave this for memory access
+	}	
 		
 		
 		
+	//liqapp_log("png.read info ");
+		
 	png_uint_32 	wd=0;
 	png_uint_32 	ht=0;
 	int 			bit_depth=0;
 	int 			color_type=0;
 
 		png_read_info(png_ptr, info_ptr);
+		
+		
+	//liqapp_log("png.get header");
+		
+		
 		png_get_IHDR(png_ptr, info_ptr, &wd, &ht, &bit_depth, &color_type, NULL, NULL, NULL);
 
 
@@ -917,6 +1098,8 @@ int liqimage_pageloadpng(liqimage *self,char * filename,int maxw,int maxh,int al
 		image.ht = ht;
 	
 	
+	//liqapp_log("png.checking color");
+	
 	int hasalpha=0;
 	int isgray=0;
 		if (color_type & PNG_COLOR_MASK_ALPHA)
@@ -940,6 +1123,10 @@ int liqimage_pageloadpng(liqimage *self,char * filename,int maxw,int maxh,int al
 			liqapp_log("gray............");
 			isgray=1;
 		}
+		
+		
+	liqapp_log("png.checking rgb expansion");
+		
 	
 		/* transfer image to RGB if not already */
 		if (color_type != PNG_COLOR_TYPE_RGB)
@@ -955,9 +1142,13 @@ int liqimage_pageloadpng(liqimage *self,char * filename,int maxw,int maxh,int al
 		//// we want RGBA
 		//png_set_filler (png_ptr, 0, PNG_FILLER_AFTER);
 	
+	
+	//liqapp_log("png.updating info");
+	
 		png_read_update_info(png_ptr, info_ptr);
 		
 		
+	//liqapp_log("png.getting rowbytes");
 		
 	png_uint_32 rowbytes = png_get_rowbytes(png_ptr, info_ptr);
 	////todo work out if this is required, i guess ill find out soon enough..
@@ -970,6 +1161,9 @@ int liqimage_pageloadpng(liqimage *self,char * filename,int maxw,int maxh,int al
 		if(image.wd & 1 )image.wd--;
 		if(image.ht & 1 )image.ht--;
 	}
+	
+	
+	liqapp_log("png.liqimage pagedefine");
 
 	
 	liqimage_pagedefine(self, image.wd, image.ht,liqcanvas_getdpix(),liqcanvas_getdpiy(), hasalpha );
@@ -1130,7 +1324,7 @@ int liqimage_pageloadpng(liqimage *self,char * filename,int maxw,int maxh,int al
 		png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
 		free(row_pointers);
 		free(image_data);
-		fclose(fp);
+		if(fp)fclose(fp);
 
 		liqapp_log("png finished");
 
