@@ -1,7 +1,42 @@
+/**
+ * @file	liqui.c
+ * @author  Gary Birkett
+ * @brief 	Libliqbase User Interface Functions
+ * 
+ * Copyright (C) 2008 Gary Birkett
+ *
+ * @section LICENSE
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *
+ */
+
 #include <string.h>
-#include "liqcell.h"
-#include "liqcell_easyrun.h"
-#include "liqbase.h"
+#include <stdlib.h>
+
+
+#include "liqui.h"
+
+
+
+#define XK_MISCELLANY
+
+#include "X11/keysymdef.h"
+
+
+char *text_temp_paste = NULL;
+
 
 //#####################################################################
 //#####################################################################
@@ -9,9 +44,13 @@
 //#####################################################################
 //#####################################################################
 
-
-
-
+/**
+ * Create a titlebar ui component
+ * @param key Name of the widget
+ * @param title Title to display
+ * @param description Describe what this titlebar is for
+ * @return liqcell* The new titlebar
+ */
 liqcell *uititlebar_create(char *key,char *title,char *description)
 {
 	
@@ -22,13 +61,13 @@ liqcell *uititlebar_create(char *key,char *title,char *description)
 		liqcell_propsets(  self,  "backcolor", "rgb(0,0,0)" );
 		
 		//texturestrip_blu.jpg
-		liqcell_setimage(  self,  liqimage_cache_getfile( "media/texturestrip_dark.jpg",0,0,0) );
+		liqcell_setimage(  self,  liqimage_cache_getfile( "/usr/share/liqbase/libliqbase/media/texturestrip_dark.jpg",0,0,0) );
 		
 		liqcell_child_append( self, liqcell_quickcreatevis("app_icon",   "icon",    5   ,10  ,    90, 80 )    );
 		liqcell_child_append( self, liqcell_quickcreatevis("app_title",  "label",   100 ,0  ,   700, 55 )    );
 		liqcell_child_append( self, liqcell_quickcreatevis("app_desc",   "label",   100 ,55 ,   700, 40 )    );
 
-		liqcell_setimage(  liqcell_child_lookup( self,"app_icon"),  liqimage_cache_getfile( "media/sun.png",0,0,1) );
+		liqcell_setimage(  liqcell_child_lookup( self,"app_icon"),  liqimage_cache_getfile( "/usr/share/liqbase/libliqbase/media/sun.png",0,0,1) );
 		liqcell_setfont(   liqcell_child_lookup( self,"app_title"), liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (40), 0) );
 		liqcell_setfont(   liqcell_child_lookup( self,"app_desc"),  liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (18), 0) );
 
@@ -66,180 +105,13 @@ liqcell *uititlebar_create(char *key,char *title,char *description)
 
 
 
-
-	// damn, this should be taken care of by the OS itself
-	// this is because the hitpoint will not always match with where I think it will be
-	// this is bad and good in practice
-	static int textbox_mouse(liqcell *self, liqcellmouseeventargs *args,void *context)
-	{
-		// if i have a font on my cell, surely it will have been rendered correctly first..
-		// infact, thats right i think
-		liqcell *base = liqcell_getbasewidget(self);
-		liqcell *body = self;
-
-		liqfont *font = liqcell_getfont(	self);
-		if(!font)return 0;
-
-		char *cap = liqcell_getcaption(self);
-		if(!cap)return 0;
-		
-		int caplen = strlen(cap);
-		
-		
-		int mx = args->mex - liqcell_getx(self);
-		
-		int chpos = liqfont_textfitinside(font,cap,mx);
-										  
-		// neat :) i know where the mouse clicked (left aligned text only...)
-		// todo: handle other alignments
-		
-		if(args->mcnt==1)
-		{
-			// start of selection..
-			liqcell_propseti(  self,  "selfirst",  chpos );
-			liqcell_propseti(  self,  "selstart",  chpos );
-			liqcell_propseti(  self,  "sellength", 0 );
-			liqcell_propseti(  self,  "cursorpos", chpos );
-		}
-		else
-		{
-			// extending selection
-			
-			int selfirst = liqcell_propgeti(  self,"selfirst",chpos);
-			int selstart;
-			int sellength;
-			
-			if(chpos<selfirst)
-			{
-				// got to invert
-				selstart=chpos;
-				sellength=selfirst-chpos;
-			}
-			else
-			{
-				selstart=selfirst;
-				sellength=chpos-selfirst;				
-			}
-
-			
-			liqcell_propseti(  self,  "selstart",  selstart );
-			liqcell_propseti(  self,  "sellength", sellength );
-			liqcell_propseti(  self,  "cursorpos", chpos );
-		}
-		
-		return 1;
-
-	}
-
-	static int textbox_keypress(liqcell *self, liqcellkeyeventargs *args,void *context)
-	{
-		liqcell *base = liqcell_getbasewidget(self);
-		// i can then use my base to access members as defined by the widget itself
-		//liqcell_setcaption(self,args->keystring);
-	
-		int selstart = liqcell_propgeti(  self,"selstart",-1);
-		int sellength = liqcell_propgeti(  self,"sellength",0);
-		int cursorpos = liqcell_propgeti(  self,"cursorpos",-1);
-		
-		char *caption = liqcell_getcaption(self);
-		int captionlen = strlen(caption);
-		
-		char *key = args->keystring;
-		int keylen = strlen(key);
-		
-		if(selstart>captionlen){ selstart=captionlen;sellength=0; }
-		
-		if(selstart+sellength>captionlen)
-		{
-			sellength = captionlen-selstart;
-		}
-		
-		
-		if(selstart>=0 && (keylen>0))
-		{
-			liqapp_log("keypress: %3i '%c'",(int)(*key),*key,args->keycode);
-			
-			if(*key==8)
-			{
-				// delete ;)
-				key="";
-				keylen=0;
-				if(selstart>0 && sellength==0)
-				{
-					selstart--;
-					sellength++;
-				}
-			}
-			
-			//
-			//liqcell_setcaption(self,args->keystring);
-			char *aftersel=&caption[selstart+sellength];
-			int aftersellen = strlen(aftersel);
-			
-			// then the result is start..selstart
-			// newbit
-			// selstart+sellen..end
-			
-			
-			// !-- BUG FIX BY ZACH HABERSANG -- !
-			// ----------------------------------
-			// Program would segfault when 25 or so characters were entered
-			// Fix: + 1 fix to reqd! :D
-			// note: used gdb with backtrace to find this bug
-			
-			// 20090615_210659 lcuk : and me to explain why it was wrong ;) damn those +1 adjustments..
-			
-			int reqd = selstart  +  keylen  +  aftersellen + 1;
-			char *buff=malloc(reqd);
-			char *block=buff;
-			if(buff)
-			{
-				if(selstart>0)
-				{
-					strncpy(block,caption,selstart);
-					block+=selstart;
-				}
-				if(keylen>0)
-				{
-					strncpy(block,key,keylen);
-					block+=keylen;
-				}
-				
-				if(aftersellen>0)
-				{
-					strncpy(block,aftersel,aftersellen);
-					block+=aftersellen;
-				}
-				*block=0;
-				liqcell_setcaption(self,buff);
-
-
-
-				
-				free(buff);
-			}
-
-			liqcell_propseti(  self,  "selstart",  selstart + keylen);
-			liqcell_propseti(  self,  "sellength", 0 );
-			liqcell_propseti(  self,  "cursorpos", selstart + keylen);			
-			
-		}
-
-	}
-	
-	static int textbox_keyrelease(liqcell *self, liqcellkeyeventargs *args)
-	{
-		liqcell *base = liqcell_getbasewidget(self);
-		// i can then use my base to access members as defined by the widget itself
-		//liqcell_setcaption(self,args->keystring);
-	}
 	
 
-
-
-
-
-
+/**
+ * Create a infobar ui component
+ * @param infotext Caption of the bar
+ * @return liqcell* The new infobar
+ */
 liqcell *uiinfobar_create(char *infotext)
 {
 	
@@ -261,9 +133,9 @@ liqcell *uiinfobar_create(char *infotext)
 			//liqcell_propseti(  body,  "sellength", 12 );
 			//liqcell_propseti(  body,  "cursorpos", 17 );
 			
-			liqcell_handleradd(body,    "mouse",      textbox_mouse);
-			liqcell_handleradd(body,    "keypress",   textbox_keypress);
-			liqcell_handleradd(body,    "keyrelease", textbox_keyrelease);
+			//liqcell_handleradd(body,    "mouse",      textbox_mouse);
+			//liqcell_handleradd(body,    "keypress",   textbox_keypress);
+			//liqcell_handleradd(body,    "keyrelease", textbox_keyrelease);
 			
 			
 		
@@ -273,20 +145,12 @@ liqcell *uiinfobar_create(char *infotext)
 	return self;
 }
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+/**
+ * Create a textbox ui component, this is the development function
+ * @param caption Body Caption
+ * @param datadefault Caption of the data
+ * @return liqcell* The new textbox
+ */
 liqcell *uitextbox_create(char *caption,char *datadefault)
 {
 	
@@ -305,7 +169,7 @@ liqcell *uitextbox_create(char *caption,char *datadefault)
 		liqcell_child_insert( self, body );
 		
 		
-			liqcell *data = liqcell_quickcreatevis("data","frame", 210,0,   580,40);
+			liqcell *data = liqcell_quickcreatevis("data","textbox", 210,0,   580,40);
 			liqcell_setfont(   data,  liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (36), 0) );
 			liqcell_propsets(  data,  "backcolor", "rgb(220,255,220)" );
 			liqcell_propsets(  data,  "textcolor", "rgb(0,0,0)" );
@@ -318,9 +182,9 @@ liqcell *uitextbox_create(char *caption,char *datadefault)
 			//liqcell_propseti(  data,  "sellength", 12 );
 			//liqcell_propseti(  data,  "cursorpos", 17 );
 			
-			liqcell_handleradd(data,    "mouse",      textbox_mouse);
-			liqcell_handleradd(data,    "keypress",   textbox_keypress);
-			liqcell_handleradd(data,    "keyrelease", textbox_keyrelease);
+		//	liqcell_handleradd(data,    "mouse",      textbox_mouse);
+		//	liqcell_handleradd(data,    "keypress",   textbox_keypress);
+		//	liqcell_handleradd(data,    "keyrelease", textbox_keyrelease);
 
 
 
@@ -343,17 +207,12 @@ liqcell *uitextbox_create(char *caption,char *datadefault)
 }
 
 
-
-
-
-
-
-
-
-
-
-
-
+/**
+ * Create a numberbox ui component
+ * @param caption The caption
+ * @param datafefault Data caption
+ * @return liqcell* The new numberbox
+ */
 liqcell *uinumberbox_create(char *caption,char *datadefault)
 {
 	
@@ -386,17 +245,12 @@ liqcell *uinumberbox_create(char *caption,char *datadefault)
 
 
 
-
-
-
-
-
-
-
-
-
-
-
+/**
+ * Create a picturebox ui component
+ * @param caption The caption
+ * @param datafefault Data caption
+ * @return liqcell* The new picturebox
+ */
 liqcell *uipicturebox_create(char *caption,char *datadefault)
 {
 	
@@ -415,7 +269,7 @@ liqcell *uipicturebox_create(char *caption,char *datadefault)
 		liqcell_child_insert( self, body );	
 		
 			liqcell *data = liqcell_quickcreatevis("data","frame", 210,0,   140,140);
-			liqcell_setimage(  data,  liqimage_cache_getfile( "media/lcuk_avatar.jpg",0,0,0) );
+			liqcell_setimage(  data,  liqimage_cache_getfile( "/usr/share/liqbase/libliqbase/media/lcuk_avatar.jpg",0,0,0) );
 
 
 		liqcell_child_insert( self, data );
@@ -427,37 +281,16 @@ liqcell *uipicturebox_create(char *caption,char *datadefault)
 
 
 
-
-
-
-
-
-
-
-
-
-
 	static int widget_mouse(liqcell *self, liqcellmouseeventargs *args)
 	{
 		liqcell_adjustpos(self,0,args->mdy);
+		return 0;
 	}
 
 
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
 liqcell *liqui_create()
 {
 	
@@ -491,16 +324,3 @@ liqcell *liqui_create()
 
 	return self;
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
