@@ -440,6 +440,8 @@ foo:
 						liqapp_log("event.WM_DELETE_WINDOW");
 						// deleting window
 						// done=1;
+						// Sat Aug 29 20:54:44 2009 lcuk : find much cleaner way to handle this
+						exit(0);
 						break;
 					}
 					liqapp_log("event.ClientMessage");
@@ -527,6 +529,16 @@ foo:
 				//############################################ focus
 				case EnterNotify:					
 					liqapp_log("event.EnterNotify");
+
+                        if(!myx11info->myoverlay)
+                        {
+                        //	liqapp_sleep(100);
+                            myx11info->myoverlay = &myx11info->myoverlaycore;
+                            liqx11overlay_init(myx11info->myoverlay, myx11info->mydisplay,myx11info->myscreen,myx11info->mywindow,myx11info->mygc);
+                            //liqx11overlay_show(myx11info->myoverlay);
+                            //isbusyrendering=0;
+                        }
+						
 						if((myx11info->myoverlay))
 						{
 							liqx11overlay_show(myx11info->myoverlay);
@@ -542,9 +554,12 @@ foo:
 	
 						if((myx11info->myoverlay))
 						{
-							liqx11overlay_show(myx11info->myoverlay);
+							liqx11overlay_hide(myx11info->myoverlay);
 							liqx11overlay_refreshdisplay(myx11info->myoverlay);
-							//isbusyrendering=1;
+
+							//liqx11overlay_show(myx11info->myoverlay);
+							//liqx11overlay_refreshdisplay(myx11info->myoverlay);
+                            //isbusyrendering=1;
 						}
 					break;				
 	
@@ -566,6 +581,9 @@ foo:
 	
 						if((myx11info->myoverlay))
 						{
+							//liqx11overlay_hide(myx11info->myoverlay);
+							//liqx11overlay_refreshdisplay(myx11info->myoverlay);
+
 							liqx11overlay_show(myx11info->myoverlay);
 							liqx11overlay_refreshdisplay(myx11info->myoverlay);
 							//isbusyrendering=1;
@@ -861,9 +879,11 @@ foo:
 								
 								myx11info->myispressedflag=1;
 								
+                if(canvas.fullscreen)
+                {
 								xev.xmotion.x= xev.xmotion.x * canvas.pixelwidth  / xres;
 								xev.xmotion.y= xev.xmotion.y * canvas.pixelheight / yres;
-								
+                }			
 								//liqapp_log("buttonpress  %i,%i",xev.xmotion.x,xev.xmotion.y);
 								//liqapp_log("ButtonPress");
 								ev->type = LIQEVENT_TYPE_MOUSE;
@@ -882,10 +902,15 @@ foo:
 								int xres   = ScreenOfDisplay (myx11info->mydisplay, DefaultScreen(myx11info->mydisplay))->width;
 								int yres   = ScreenOfDisplay (myx11info->mydisplay, DefaultScreen(myx11info->mydisplay))->height;
 								
+                                
+                //                int qx=xev.xmotion.x;
+                //                int qy=xev.xmotion.y;
+                if(canvas.fullscreen)
+                {
 								xev.xmotion.x= xev.xmotion.x * canvas.pixelwidth  / xres;
 								xev.xmotion.y= xev.xmotion.y * canvas.pixelheight / yres;
-						 
-								//liqapp_log("motion %i,%i",xev.xmotion.x,xev.xmotion.y);
+                }		 
+				//				liqapp_log("motion %i,%i (q %i,%i) (can %i,%i)",xev.xmotion.x,xev.xmotion.y,qx,qy,canvas.pixelwidth,canvas.pixelheight);
 								ev->type = LIQEVENT_TYPE_MOUSE;
 								ev->mouse.state = LIQEVENT_STATE_MOVE;
 								ev->mouse.x = ((xev.xmotion.x));// *800)/canvas.pixelwidth;
@@ -903,9 +928,11 @@ foo:
 								
 								myx11info->myispressedflag=0;
 								
+                if(canvas.fullscreen)
+                {
 								xev.xmotion.x= xev.xmotion.x * canvas.pixelwidth  / xres;
 								xev.xmotion.y= xev.xmotion.y * canvas.pixelheight / yres;
-						 
+                }		 
 								//liqapp_log("release %i,%i",xev.xmotion.x,xev.xmotion.y);
 						
 								//liqapp_log("ButtonRelease");
